@@ -3,15 +3,15 @@
 # The copyright notice and plain old documentation (POD)
 # are at the end of this file.
 #
-package  Test::STDmaker::tgC1;
+package  t::Test::STDmaker::tgC1;
 
 use strict;
 use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.01';
-$DATE = '2003/06/14';
+$VERSION = '0.02';
+$DATE = '2003/06/21';
 $FILE = __FILE__;
 
 ########
@@ -49,11 +49,11 @@ Verify: ccc/tg1B.t^
  C: my $x = 2^
  C: my $y = 3^
  A: $x + $y^
-SE: '5'^
+SE: 5^
 ok: 1^
 
- A: ($x+$y,$y-$x)^
- E: '5','1'^
+ A: $y-$x^
+ E: 1^
 ok: 2^
 
 
